@@ -33,7 +33,7 @@ import pygame
 from pygame.constants import *
 
 import utils
-from utils import load_music,font2surf,MyError,ChildsplayGoodies,trace_error
+from utils import load_music,font2surf,MyError,trace_error
 from SpriteUtils import CPSprite,CPGroup,CPinit
 import Timer
 
@@ -161,7 +161,7 @@ class Card:
 class Game(Img,Snd):    
     """  letterFlashcard - part of childsplay.py, a suite of educational games for
     young children. """
-    def __init__(self,screen,backgr,rc_dic,basepath,libdir):
+    def __init__(self,screen,backgr,rc_dic,basepath,libdir,cpg):
         self.screen = screen# SDL screen representing the visible screen
         self.backgr = backgr# A SDL surface which holds a copy of 'screen'
 
@@ -171,6 +171,7 @@ class Game(Img,Snd):
         self.rc_dic = rc_dic# reference to the rcfile, if we have one, otherwise {}
         self.basedir  = basepath# path to the childsplay core directory
         self.libdir = libdir# path to the 'lib' directory which holds this file.
+        self.cpg = cpg
         #~ self.Assets_snd = pyassetmlSDL.AssetmlSDL()
         #~ self.Assets_snd.set_mldir('childsplay/childsplay-sounds/childsplay-sounds.assetml')
         self.gamelevels =[1]# used by childsplay core (see childsplaytest.py)
@@ -179,32 +180,7 @@ class Game(Img,Snd):
         self._setup()
        
     def __del__(self):
-        """If you use the timer object y> 
-> I had no time to prepare a patch to fix it last weekend, if somebody is
-> interested in doing it please tell me; otherwise I'll try to do it this
-> weekend.
-> 
-> Greetings,
-> 
->   Sergio.
-> 
-> --
-> Sergio Talens-Oliag <sto@debian.org>   <http://people.debian.org/~sto/>
-> Key fingerprint = 29DF 544F  1BD9 548C  8F15 86EF  6770 052B  B8C1 FA69
-> 
-> 
-> -----BEGIN PGP SIGNATURE-----
-> Version: GnuPG v1.4.1 (GNU/Linux)
-> 
-> iD8DBQFD/Xy3Z3AFK7jB+mkRAnPcAJ4x7QZNUQqyoVJnmC0T69BSO/n7hACgvZl/
-> FGXZiJfAA+9MBeHNd/Lq3w0=
-> =srz4
-> -----END PGP SIGNATURE-----
-> 
-> 
-> 
-
-ou MUST stop it."""
+        """If you use the timer object you MUST stop it."""
         print "del called"
         try:
             self.timer.stop()
@@ -227,7 +203,7 @@ ou MUST stop it."""
                                     step=20,\
                                     ttf=os.path.join(DATADIR,'VeraSeBd.ttf'))
         self.updatebar()
-        if LF_DEBUG: print "ChildsplayGoodies",dir(ChildsplayGoodies)
+        if LF_DEBUG: print "ChildsplayGoodies",dir(self.cpg)
         ## This is only needed when you decide to use assetml files.
         ## If you don't know what 'Assetml' is you probably don't need it :-)
         try:
@@ -237,7 +213,7 @@ ou MUST stop it."""
             text = "Module memory fails to import pyassetmlSDL"
             raise MyError,text
 
-        loc = ChildsplayGoodies.language
+        loc = self.cpg.language
         if loc not in SUPPORTED_LOCALES:
             loc = 'en'
         if LF_DEBUG: print "letterFlashcard game, locale set to",loc
